package
Version:
v0.0.0-...-c622dda
Opens a new window with list of versions in this module.
Published: Mar 29, 2026
License: AGPL-3.0
Opens a new window with license information.
Imports: 18
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Bootstrap struct {
}
Bootstrap アプリケーションの起動を管理する
New 新しいBootstrapインスタンスを作成する
Shutdown アプリケーションを適切にシャットダウンする
Source Files
¶
Click to show internal directories.
Click to hide internal directories.